summaryrefslogtreecommitdiffstats
path: root/filters/kword/pdf
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /filters/kword/pdf
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'filters/kword/pdf')
-rw-r--r--filters/kword/pdf/FilterDevice.cpp10
-rw-r--r--filters/kword/pdf/FilterDevice.h4
-rw-r--r--filters/kword/pdf/dialog.h2
-rw-r--r--filters/kword/pdf/pdfimport.h2
-rw-r--r--filters/kword/pdf/xpdf/xpdf/FontFile.cc12
-rw-r--r--filters/kword/pdf/xpdf/xpdf/Gfx.cc16
-rw-r--r--filters/kword/pdf/xpdf/xpdf/JBIG2Stream.cc10
-rw-r--r--filters/kword/pdf/xpdf/xpdf/PBMOutputDev.cc2
-rw-r--r--filters/kword/pdf/xpdf/xpdf/PSOutputDev.cc8
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XOutputDev.cc28
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFCore.cc4
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFCore.h2
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFTree.cc12
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFTree.h2
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFViewer.cc6
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFViewer.h2
16 files changed, 61 insertions, 61 deletions
diff --git a/filters/kword/pdf/FilterDevice.cpp b/filters/kword/pdf/FilterDevice.cpp
index b47770c65..5182f1883 100644
--- a/filters/kword/pdf/FilterDevice.cpp
+++ b/filters/kword/pdf/FilterDevice.cpp
@@ -255,7 +255,7 @@ uint Device::initImage(GfxState *state, int width, int height,
{
// get image tqgeometry
Image image;
- image.tqmask = withMask;
+ image.mask = withMask;
computeGeometry(state, image);
// check if new image
@@ -263,17 +263,17 @@ uint Device::initImage(GfxState *state, int width, int height,
// << " " << _currentImage.rect.left()
// << " " << _currentImage.rect.right()
// << " " << _currentImage.rect.bottom()
-// << " " << _currentImage.tqmask << endl;
+// << " " << _currentImage.mask << endl;
// kdDebug(30516) << "new image " << width
// << " " << image.rect.left() << " " << image.rect.right()
// << " " << image.rect.top()
-// << " " << image.tqmask << endl;
+// << " " << image.mask << endl;
if ( !_currentImage.image.isNull() &&
(_currentImage.image.width()!=width
|| !equal(image.rect.left(), _currentImage.rect.left())
|| !equal(image.rect.right(), _currentImage.rect.right())
|| !equal(image.rect.top(), _currentImage.rect.bottom())
- || image.tqmask!=_currentImage.tqmask) )
+ || image.mask!=_currentImage.mask) )
addImage();
uint offset =
@@ -335,7 +335,7 @@ void Device::drawImageMask(GfxState *state, Object *, Stream *str,
int width, int height, GBool invert,
GBool inlineImg)
{
- kdDebug(30516) << "image tqmask ! kind=" << str->getKind()
+ kdDebug(30516) << "image mask ! kind=" << str->getKind()
<< "inline=" << inlineImg << endl;
if ( !_data.options().importImages ) return;
diff --git a/filters/kword/pdf/FilterDevice.h b/filters/kword/pdf/FilterDevice.h
index 7c4590fac..be106d8d5 100644
--- a/filters/kword/pdf/FilterDevice.h
+++ b/filters/kword/pdf/FilterDevice.h
@@ -96,7 +96,7 @@ public:
private:
class Image;
static void computeGeometry(GfxState *, Image &);
- uint initImage(GfxState *, int width, int height, bool tqmask);
+ uint initImage(GfxState *, int width, int height, bool mask);
void addImage();
void clear();
static DPathVector convertPath(GfxState *);
@@ -112,7 +112,7 @@ private:
public:
TQImage image;
DRect rect;
- bool tqmask;
+ bool mask;
};
Image _currentImage;
typedef TQValueList<Image> ImageList;
diff --git a/filters/kword/pdf/dialog.h b/filters/kword/pdf/dialog.h
index 128f9b18b..a5b6150a5 100644
--- a/filters/kword/pdf/dialog.h
+++ b/filters/kword/pdf/dialog.h
@@ -82,7 +82,7 @@ class Dialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- Dialog(uint nbPages, bool isEncrypted, TQWidget *tqparent);
+ Dialog(uint nbPages, bool isEncrypted, TQWidget *parent);
~Dialog();
Options options() const;
diff --git a/filters/kword/pdf/pdfimport.h b/filters/kword/pdf/pdfimport.h
index 66b685253..9686714ea 100644
--- a/filters/kword/pdf/pdfimport.h
+++ b/filters/kword/pdf/pdfimport.h
@@ -31,7 +31,7 @@ class PdfImport : public KoFilter
Q_OBJECT
TQ_OBJECT
public:
- PdfImport(KoFilter *tqparent, const char *name, const TQStringList&);
+ PdfImport(KoFilter *parent, const char *name, const TQStringList&);
KoFilter::ConversiontqStatus
convert(const TQCString& from, const TQCString& to);
diff --git a/filters/kword/pdf/xpdf/xpdf/FontFile.cc b/filters/kword/pdf/xpdf/xpdf/FontFile.cc
index 283963380..73a7f1d35 100644
--- a/filters/kword/pdf/xpdf/xpdf/FontFile.cc
+++ b/filters/kword/pdf/xpdf/xpdf/FontFile.cc
@@ -1111,7 +1111,7 @@ void Type1CFontFile::convertToType0(const char *psName,
(*outputFunc)(outputStream, "cleartomark\n", 12);
}
- // write the Type 0 tqparent font
+ // write the Type 0 parent font
(*outputFunc)(outputStream, "16 dict begin\n", 14);
(*outputFunc)(outputStream, "/FontName /", 11);
(*outputFunc)(outputStream, psName, strlen(psName));
@@ -1572,7 +1572,7 @@ void Type1CFontFile::cvtGlyph(const Guchar *s, int n) {
}
i += 2;
nOps = 0;
- } else if (s[i] == 19) { // hinttqmask
+ } else if (s[i] == 19) { // hintmask
// ignored
if (first) {
cvtGlyphWidth(nOps == 1);
@@ -1580,14 +1580,14 @@ void Type1CFontFile::cvtGlyph(const Guchar *s, int n) {
}
if (nOps > 0) {
if (nOps & 1) {
- error(-1, "Wrong number of args (%d) to Type 2 hinttqmask/vstemhm",
+ error(-1, "Wrong number of args (%d) to Type 2 hintmask/vstemhm",
nOps);
}
nHints += nOps / 2;
}
i += 1 + ((nHints + 7) >> 3);
nOps = 0;
- } else if (s[i] == 20) { // cntrtqmask
+ } else if (s[i] == 20) { // cntrmask
// ignored
if (first) {
cvtGlyphWidth(nOps == 1);
@@ -1595,7 +1595,7 @@ void Type1CFontFile::cvtGlyph(const Guchar *s, int n) {
}
if (nOps > 0) {
if (nOps & 1) {
- error(-1, "Wrong number of args (%d) to Type 2 cntrtqmask/vstemhm",
+ error(-1, "Wrong number of args (%d) to Type 2 cntrmask/vstemhm",
nOps);
}
nHints += nOps / 2;
@@ -3063,7 +3063,7 @@ void TrueTypeFontFile::convertToType0(const char *name, const Gushort *cidMap,
"FontName currentdict end definefont pop\n", 40);
}
- // write the Type 0 tqparent font
+ // write the Type 0 parent font
(*outputFunc)(outputStream, "16 dict begin\n", 14);
(*outputFunc)(outputStream, "/FontName /", 11);
(*outputFunc)(outputStream, name, strlen(name));
diff --git a/filters/kword/pdf/xpdf/xpdf/PBMOutputDev.cc b/filters/kword/pdf/xpdf/xpdf/PBMOutputDev.cc
index 453b08620..34432991d 100644
--- a/filters/kword/pdf/xpdf/xpdf/PBMOutputDev.cc
+++ b/filters/kword/pdf/xpdf/xpdf/PBMOutputDev.cc
@@ -72,7 +72,7 @@ void PBMOutputDev::killPBMOutputDev(PBMOutputDev *out) {
delete out;
- // these have to be done *after* the XOutputDev (tqparent of the
+ // these have to be done *after* the XOutputDev (parent of the
// PBMOutputDev) is deleted, since XOutputDev::~XOutputDev() needs
// them
XFreePixmap(displayA, pixmapA);
diff --git a/filters/kword/pdf/xpdf/xpdf/PSOutputDev.cc b/filters/kword/pdf/xpdf/xpdf/PSOutputDev.cc
index 671d0599a..111d8717b 100644
--- a/filters/kword/pdf/xpdf/xpdf/PSOutputDev.cc
+++ b/filters/kword/pdf/xpdf/xpdf/PSOutputDev.cc
@@ -315,7 +315,7 @@ static char *prolog[] = {
"} def",
"/pdfImM1 {",
" /pdfImBuf1 4 index 7 add 8 idiv string def",
- " { currentfile pdfImBuf1 readhexstring pop } imagetqmask",
+ " { currentfile pdfImBuf1 readhexstring pop } imagemask",
"} def",
"% Level 2 image operators",
"/pdfImBuf 100 string def",
@@ -340,7 +340,7 @@ static char *prolog[] = {
" (%-EOD-) eq { exit } if } loop",
"} def",
"/pdfImM {",
- " fCol imagetqmask",
+ " fCol imagemask",
" { currentfile pdfImBuf readline",
" not { pop exit } if",
" (%-EOD-) eq { exit } if } loop",
@@ -2287,7 +2287,7 @@ void PSOutputDev::doImageL1(GfxImageColorMap *colorMap,
}
delete imgStr;
- // imagetqmask
+ // imagemask
} else {
str->reset();
i = 0;
@@ -2478,7 +2478,7 @@ void PSOutputDev::doImageL2(Object *ref, GfxImageColorMap *colorMap,
writePS(" /DataSource { 2 copy get exch 1 add exch }\n");
// end of image dictionary
- writePSFmt(">>\n%s\n", colorMap ? "image" : "imagetqmask");
+ writePSFmt(">>\n%s\n", colorMap ? "image" : "imagemask");
// get rid of the array and index
writePS("pop pop\n");
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFCore.cc b/filters/kword/pdf/xpdf/xpdf/XPDFCore.cc
index 5c53ade12..8376ce97d 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFCore.cc
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFCore.cc
@@ -302,7 +302,7 @@ int XPDFCore::loadFile(GString *fileName, GString *ownerPassword,
// save the modification time
modTime = getModTime(doc->getFileName()->getCString());
- // update the tqparent window
+ // update the parent window
if (updateCbk) {
(*updateCbk)(updateCbkData, doc->getFileName(), -1,
doc->getNumPages(), NULL);
@@ -495,7 +495,7 @@ void XPDFCore::displayPage(int pageA, int zoomA, int rotateA,
historyFLen = 0;
}
- // update the tqparent window
+ // update the parent window
if (updateCbk) {
(*updateCbk)(updateCbkData, NULL, page, -1, "");
}
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFCore.h b/filters/kword/pdf/xpdf/xpdf/XPDFCore.h
index adc7f5073..348486f0f 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFCore.h
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFCore.h
@@ -229,7 +229,7 @@ private:
Visual *visual;
Colormap colormap;
Widget shell; // top-level shell containing the widget
- Widget parentWidget; // tqparent widget (not created by XPDFCore)
+ Widget parentWidget; // parent widget (not created by XPDFCore)
Widget scrolledWin;
Widget hScrollBar;
Widget vScrollBar;
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFTree.h b/filters/kword/pdf/xpdf/xpdf/XPDFTree.h
index 93e3fb77a..d569f4987 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFTree.h
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFTree.h
@@ -35,7 +35,7 @@ typedef struct {
Widget selectedItem;
} XPDFTreeSelectCallbackStruct;
-extern Widget XPDFCreateTree(Widget tqparent, char *name,
+extern Widget XPDFCreateTree(Widget parent, char *name,
ArgList argList, Cardinal argCount);
} // extern "C"
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFViewer.cc b/filters/kword/pdf/xpdf/xpdf/XPDFViewer.cc
index a75830b83..de691914e 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFViewer.cc
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFViewer.cc
@@ -1484,7 +1484,7 @@ void XPDFViewer::setupOutline() {
XtManageChildren(outlineLabels, outlineLabelsLength);
}
-void XPDFViewer::setupOutlineItems(GList *items, Widget tqparent,
+void XPDFViewer::setupOutlineItems(GList *items, Widget parent,
UnicodeMap *uMap) {
OutlineItem *item;
GList *kids;
@@ -1504,8 +1504,8 @@ void XPDFViewer::setupOutlineItems(GList *items, Widget tqparent,
}
n = 0;
XtSetArg(args[n], XPDFNentryPosition, i); ++n;
- if (tqparent) {
- XtSetArg(args[n], XPDFNentryParent, tqparent); ++n;
+ if (parent) {
+ XtSetArg(args[n], XPDFNentryParent, parent); ++n;
}
XtSetArg(args[n], XPDFNentryExpanded, item->isOpen()); ++n;
s = XmStringCreateLocalized(title->getCString());
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFViewer.h b/filters/kword/pdf/xpdf/xpdf/XPDFViewer.h
index b9b0b2dab..77875c416 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFViewer.h
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFViewer.h
@@ -124,7 +124,7 @@ private:
//----- GUI code: outline
#ifndef DISABLE_OUTLINE
void setupOutline();
- void setupOutlineItems(GList *items, Widget tqparent, UnicodeMap *uMap);
+ void setupOutlineItems(GList *items, Widget parent, UnicodeMap *uMap);
static void outlineSelectCbk(Widget widget, XtPointer ptr,
XtPointer callData);
#endif
diff --git a/filters/kword/pdf/xpdf/xpdf/Gfx.cc b/filters/kword/pdf/xpdf/xpdf/Gfx.cc
index 53999975e..7948d78ae 100644
--- a/filters/kword/pdf/xpdf/xpdf/Gfx.cc
+++ b/filters/kword/pdf/xpdf/xpdf/Gfx.cc
@@ -2259,7 +2259,7 @@ void Gfx::doImage(Object *ref, Stream *str, GBool inlineImg) {
Dict *dict;
int width, height;
int bits;
- GBool tqmask;
+ GBool mask;
GBool invert;
GfxColorSpace *colorSpace;
GfxImageColorMap *colorMap;
@@ -2292,15 +2292,15 @@ void Gfx::doImage(Object *ref, Stream *str, GBool inlineImg) {
height = obj1.getInt();
obj1.free();
- // image or tqmask?
+ // image or mask?
dict->lookup("ImageMask", &obj1);
if (obj1.isNull()) {
obj1.free();
dict->lookup("IM", &obj1);
}
- tqmask = gFalse;
+ mask = gFalse;
if (obj1.isBool())
- tqmask = obj1.getBool();
+ mask = obj1.getBool();
else if (!obj1.isNull())
goto err2;
obj1.free();
@@ -2316,10 +2316,10 @@ void Gfx::doImage(Object *ref, Stream *str, GBool inlineImg) {
bits = obj1.getInt();
obj1.free();
- // display a tqmask
- if (tqmask) {
+ // display a mask
+ if (mask) {
- // check for inverted tqmask
+ // check for inverted mask
if (bits != 1)
goto err1;
invert = gFalse;
@@ -2375,7 +2375,7 @@ void Gfx::doImage(Object *ref, Stream *str, GBool inlineImg) {
goto err1;
}
- // get the tqmask
+ // get the mask
haveMask = gFalse;
dict->lookup("Mask", &maskObj);
if (maskObj.isArray()) {
diff --git a/filters/kword/pdf/xpdf/xpdf/JBIG2Stream.cc b/filters/kword/pdf/xpdf/xpdf/JBIG2Stream.cc
index ec76e1ccf..6312cacae 100644
--- a/filters/kword/pdf/xpdf/xpdf/JBIG2Stream.cc
+++ b/filters/kword/pdf/xpdf/xpdf/JBIG2Stream.cc
@@ -682,11 +682,11 @@ GBool JBIG2HuffmanDecoder::decodeInt(int *x, JBIG2HuffmanTable *table) {
}
Guint JBIG2HuffmanDecoder::readBits(Guint n) {
- Guint x, tqmask, nLeft;
+ Guint x, mask, nLeft;
- tqmask = (n == 32) ? 0xffffffff : ((1 << n) - 1);
+ mask = (n == 32) ? 0xffffffff : ((1 << n) - 1);
if (bufLen >= n) {
- x = (buf >> (bufLen - n)) & tqmask;
+ x = (buf >> (bufLen - n)) & mask;
bufLen -= n;
} else {
x = buf & ((1 << bufLen) - 1);
@@ -1101,7 +1101,7 @@ void JBIG2Bitmap::combine(JBIG2Bitmap *bitmap, int x, int y,
for (yy = y0; yy < y1; ++yy) {
// one byte per line -- need to tqmask both left and right side
if (oneByte) {
if (x >= 0) {
destPtr = data + (y + yy) * line + (x >> 3);
@@ -1151,7 +1151,7 @@ void JBIG2Bitmap::combine(JBIG2Bitmap *bitmap, int x, int y,
*destPtr = dest;
}
// multiple bytes per line -- need to tqmask left side of left-most
// byte and right side of right-most byte
} else {
@@ -1101,7 +1101,7 @@ void JBIG2Bitmap::combine(JBIG2Bitmap *bitmap, int x, int y,
for (yy = y0; yy < y1; ++yy) {
- // one byte per line -- need to tqmask both left and right side
+ // one byte per line -- need to mask both left and right side
if (oneByte) {
if (x >= 0) {
@@ -1151,7 +1151,7 @@ void JBIG2Bitmap::combine(JBIG2Bitmap *bitmap, int x, int y,
*destPtr = dest;
}
- // multiple bytes per line -- need to tqmask left side of left-most
+ // multiple bytes per line -- need to mask left side of left-most
// byte and right side of right-most byte
} else {
diff --git a/filters/kword/pdf/xpdf/xpdf/XOutputDev.cc b/filters/kword/pdf/xpdf/xpdf/XOutputDev.cc
index dc37ee218..3c58f5650 100644
--- a/filters/kword/pdf/xpdf/xpdf/XOutputDev.cc
+++ b/filters/kword/pdf/xpdf/xpdf/XOutputDev.cc
@@ -1627,7 +1627,7 @@ XOutputDev::XOutputDev(Display *displayA, int screenNumA,
XVisualInfo visualTempl;
XVisualInfo *visualList;
int nVisuals;
- Gulong tqmask;
+ Gulong mask;
XColor xcolor;
XColor *xcolors;
int r, g, b, n, m;
@@ -1662,18 +1662,18 @@ XOutputDev::XOutputDev(Display *displayA, int screenNumA,
depth = visualList->depth;
if (visualList->c_class == TrueColor) {
trueColor = gTrue;
- for (tqmask = visualList->red_tqmask, rShift = 0;
- tqmask && !(tqmask & 1);
- tqmask >>= 1, ++rShift) ;
- rMul = (int)tqmask;
- for (tqmask = visualList->green_tqmask, gShift = 0;
- tqmask && !(tqmask & 1);
- tqmask >>= 1, ++gShift) ;
- gMul = (int)tqmask;
- for (tqmask = visualList->blue_tqmask, bShift = 0;
- tqmask && !(tqmask & 1);
- tqmask >>= 1, ++bShift) ;
- bMul = (int)tqmask;
+ for (mask = visualList->red_mask, rShift = 0;
+ mask && !(mask & 1);
+ mask >>= 1, ++rShift) ;
+ rMul = (int)mask;
+ for (mask = visualList->green_mask, gShift = 0;
+ mask && !(mask & 1);
+ mask >>= 1, ++gShift) ;
+ gMul = (int)mask;
+ for (mask = visualList->blue_mask, bShift = 0;
+ mask && !(mask & 1);
+ mask >>= 1, ++bShift) ;
+ bMul = (int)mask;
} else {
trueColor = gFalse;
}
@@ -3162,7 +3162,7 @@ void XOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
XGetSubImage(display, pixmap, cx0, cy0, cw, ch, (1 << depth) - 1, ZPixmap,
image, cx1, cy1);
// get tqmask color
state->getFillRGB(&rgb);
if (reverseVideo) {
rgb.r = 1 - rgb.r;
@@ -3162,7 +3162,7 @@ void XOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
XGetSubImage(display, pixmap, cx0, cy0, cw, ch, (1 << depth) - 1, ZPixmap,
image, cx1, cy1);
- // get tqmask color
+ // get mask color
state->getFillRGB(&rgb);
if (reverseVideo) {
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc b/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc
index 28e01de6c..290861b94 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc
@@ -393,7 +393,7 @@ static void setValuesAlmost(Widget oldWidget, Widget newWidget,
XtWidgetGeometry *reply) {
XPDFTreeWidgetClass cls = (XPDFTreeWidgetClass)XtClass(newWidget);
// our tqparent rejected a tqgeometry request, so accept the compromise
// and retqlayout
if (!reply->request_mode) {
if (cls->treeClass.tqlayout) {
@@ -480,7 +480,7 @@ static XtGeometryResult geometryManager(Widget widget,
calcSize((Widget)w, widget, &parentReq.width, &reply->height);
}
// send tqgeometry request to our tqparent
parentReq.request_mode = CWWidth | CWHeight;
if (request->request_mode & XtCWQueryOnly) {
parentReq.request_mode |= XtCWQueryOnly;
@@ -524,7 +524,7 @@ static void changeManaged(Widget widget) {
calcSize(widget, NULL, &width, &height);
}
// make resize request to tqparent -- keep asking until we get a yes
// or no
while (XtMakeResizeRequest(widget, width, height, &width, &height)
== XtGeometryAlmost) ;
@@ -629,7 +629,7 @@ static Boolean constraintSetValues(Widget oldWidget, Widget requestWidget,
calcSize((Widget)w, NULL, &width, &height);
}
// make resize request to tqparent -- keep asking until we get a yes
// or no
while (XtMakeResizeRequest((Widget)w, width, height, &width, &height)
== XtGeometryAlmost) ;
@@ -923,7 +923,7 @@ static Boolean findPositionInSubtree(XPDFTreeWidget w, int x, int y,
return False;
}
-Widget XPDFCreateTree(Widget tqparent, char *name,
+Widget XPDFCreateTree(Widget parent, char *name,
ArgList argList, Cardinal numArgs) {
- return XtCreateWidget(name, xpdfTreeWidgetClass, tqparent, argList, numArgs);
+ return XtCreateWidget(name, xpdfTreeWidgetClass, parent, argList, numArgs);
}
@@ -393,7 +393,7 @@ static void setValuesAlmost(Widget oldWidget, Widget newWidget,
XtWidgetGeometry *reply) {
XPDFTreeWidgetClass cls = (XPDFTreeWidgetClass)XtClass(newWidget);
- // our tqparent rejected a tqgeometry request, so accept the compromise
+ // our parent rejected a tqgeometry request, so accept the compromise
// and retqlayout
if (!reply->request_mode) {
@@ -480,7 +480,7 @@ static XtGeometryResult geometryManager(Widget widget,
calcSize((Widget)w, widget, &parentReq.width, &reply->height);
}
- // send tqgeometry request to our tqparent
+ // send tqgeometry request to our parent
parentReq.request_mode = CWWidth | CWHeight;
if (request->request_mode & XtCWQueryOnly) {
@@ -524,7 +524,7 @@ static void changeManaged(Widget widget) {
calcSize(widget, NULL, &width, &height);
}
- // make resize request to tqparent -- keep asking until we get a yes
+ // make resize request to parent -- keep asking until we get a yes
// or no
while (XtMakeResizeRequest(widget, width, height, &width, &height)
@@ -629,7 +629,7 @@ static Boolean constraintSetValues(Widget oldWidget, Widget requestWidget,
calcSize((Widget)w, NULL, &width, &height);
}
- // make resize request to tqparent -- keep asking until we get a yes
+ // make resize request to parent -- keep asking until we get a yes
// or no
while (XtMakeResizeRequest((Widget)w, width, height, &width, &height)